@@ -16,46 +16,41 @@ namespace net {
 
 nsStreamLoader::nsStreamLoader() : mData() {}
 
-nsStreamLoader::~nsStreamLoader() {}
-
 NS_IMETHODIMP
-nsStreamLoader::Init(nsIStreamLoaderObserver *aStreamObserver,
-                     nsIRequestObserver *aRequestObserver) {
+nsStreamLoader::Init(nsIStreamLoaderObserver* aStreamObserver,
+                     nsIRequestObserver* aRequestObserver) {
   NS_ENSURE_ARG_POINTER(aStreamObserver);
   mObserver = aStreamObserver;
   mRequestObserver = aRequestObserver;
   return NS_OK;
 }
 
-nsresult nsStreamLoader::Create(nsISupports *aOuter, REFNSIID aIID,
-                                void **aResult) {
+nsresult nsStreamLoader::Create(nsISupports* aOuter, REFNSIID aIID,
+                                void** aResult) {
   if (aOuter) return NS_ERROR_NO_AGGREGATION;
 
-  nsStreamLoader *it = new nsStreamLoader();
-  if (it == nullptr) return NS_ERROR_OUT_OF_MEMORY;
-  NS_ADDREF(it);
-  nsresult rv = it->QueryInterface(aIID, aResult);
-  NS_RELEASE(it);
-  return rv;
+  RefPtr<nsStreamLoader> it = new nsStreamLoader();
+  return it->QueryInterface(aIID, aResult);
 }
 
 NS_IMPL_ISUPPORTS(nsStreamLoader, nsIStreamLoader, nsIRequestObserver,
                   nsIStreamListener, nsIThreadRetargetableStreamListener)
 
 NS_IMETHODIMP
-nsStreamLoader::GetNumBytesRead(uint32_t *aNumBytes) {
+nsStreamLoader::GetNumBytesRead(uint32_t* aNumBytes) {
   *aNumBytes = mData.length();
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsStreamLoader::GetRequest(nsIRequest **aRequest) {
-  NS_IF_ADDREF(*aRequest = mRequest);
+nsStreamLoader::GetRequest(nsIRequest** aRequest) {
+  nsCOMPtr<nsIRequest> req = mRequest;
+  req.forget(aRequest);
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsStreamLoader::OnStartRequest(nsIRequest *request, nsISupports *ctxt) {
+nsStreamLoader::OnStartRequest(nsIRequest* request) {
   nsCOMPtr<nsIChannel> chan(do_QueryInterface(request));
   if (chan) {
     int64_t contentLength = -1;
@@ -75,23 +70,21 @@ nsStreamLoader::OnStartRequest(nsIRequest *request, nsISupports *ctxt) {
       }
     }
   }
-  mContext = ctxt;
   if (mRequestObserver) {
-    mRequestObserver->OnStartRequest(request, ctxt);
+    mRequestObserver->OnStartRequest(request);
   }
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsStreamLoader::OnStopRequest(nsIRequest *request, nsISupports *ctxt,
-                              nsresult aStatus) {
+nsStreamLoader::OnStopRequest(nsIRequest* request, nsresult aStatus) {
   AUTO_PROFILER_LABEL("nsStreamLoader::OnStopRequest", NETWORK);
 
   if (mObserver) {
     // provide nsIStreamLoader::request during call to OnStreamComplete
     mRequest = request;
     size_t length = mData.length();
-    uint8_t *elems = mData.extractOrCopyRawBuffer();
+    uint8_t* elems = mData.extractOrCopyRawBuffer();
     nsresult rv =
         mObserver->OnStreamComplete(this, mContext, aStatus, length, elems);
     if (rv != NS_SUCCESS_ADOPTED_DATA) {
@@ -103,22 +96,21 @@ nsStreamLoader::OnStopRequest(nsIRequest *request, nsISupports *ctxt,
     ReleaseData();
     mRequest = nullptr;
     mObserver = nullptr;
-    mContext = nullptr;
   }
 
   if (mRequestObserver) {
-    mRequestObserver->OnStopRequest(request, ctxt, aStatus);
+    mRequestObserver->OnStopRequest(request, aStatus);
     mRequestObserver = nullptr;
   }
 
   return NS_OK;
 }
 
-nsresult nsStreamLoader::WriteSegmentFun(nsIInputStream *inStr, void *closure,
-                                         const char *fromSegment,
+nsresult nsStreamLoader::WriteSegmentFun(nsIInputStream* inStr, void* closure,
+                                         const char* fromSegment,
                                          uint32_t toOffset, uint32_t count,
-                                         uint32_t *writeCount) {
-  nsStreamLoader *self = (nsStreamLoader *)closure;
+                                         uint32_t* writeCount) {
+  nsStreamLoader* self = (nsStreamLoader*)closure;
 
   if (!self->mData.append(fromSegment, count)) {
     self->mData.clearAndFree();
@@ -131,9 +123,8 @@ nsresult nsStreamLoader::WriteSegmentFun(nsIInputStream *inStr, void *closure,
 }
 
 NS_IMETHODIMP
-nsStreamLoader::OnDataAvailable(nsIRequest *request, nsISupports *ctxt,
-                                nsIInputStream *inStr, uint64_t sourceOffset,
-                                uint32_t count) {
+nsStreamLoader::OnDataAvailable(nsIRequest* request, nsIInputStream* inStr,
+                                uint64_t sourceOffset, uint32_t count) {
   uint32_t countRead;
   return inStr->ReadSegments(WriteSegmentFun, this, count, &countRead);
 }
